@@ -7,10 +7,14 @@ from logging import getLogger
 from zlib import decompress
 from zlib import ZLIB_VERSION
 
-from untanglepyut.UnTangler import Documents
+from untanglepyut.Types import Documents
+from untanglepyut.Types import ProjectInformation
+
+from untanglepyut.UnTangleProjectInformation import UnTangleProjectInformation
+
 from untanglepyut.UnTangler import UnTangler
+from untanglepyut.XmlVersion import XmlVersion
 
-from oglio import OglVersion
 from oglio.Types import OglActors
 from oglio.Types import OglClasses
 from oglio.Types import OglDocument
@@ -23,6 +27,7 @@ from oglio.Types import OglSDInstances
 from oglio.Types import OglSDMessages
 
 from oglio.UnsupportedFileTypeException import UnsupportedFileTypeException
+from oglio.UnsupportedVersion import UnsupportedVersion
 
 
 class Reader:
@@ -47,18 +52,21 @@ class Reader:
         if fqFileName.endswith('.put') is False:
             raise UnsupportedFileTypeException(message=f'File does not end with .put suffix')
 
-        rawXmlString: str = self._decompressFile(fqFileName=fqFileName)
+        rawXmlString:       str                = self._decompressFile(fqFileName=fqFileName)
+        projectInformation: ProjectInformation = self._extractProjectInformation(fqFileName)
 
-        untangler: UnTangler = UnTangler()
+        if projectInformation.version == XmlVersion.V10.value:
+            untangler: UnTangler = UnTangler(xmlVersion=XmlVersion.V10)
+        else:
+            untangler = UnTangler(xmlVersion=XmlVersion.V11)
 
-        untangler.untangleXml(xmlString=rawXmlString)
+        untangler.untangleXml(xmlString=rawXmlString, fqFileName=fqFileName)
 
         oglProject: OglProject = self._makeOglProject(untangler=untangler)
 
         return oglProject
 
     def readXmlFile(self, fqFileName: str) -> OglProject:
-
         """
         Parse the input XML file;
 
@@ -68,7 +76,14 @@ class Reader:
         if fqFileName.endswith('.xml') is False:
             raise UnsupportedFileTypeException(message=f'File does not end with .xml suffix')
 
-        untangler: UnTangler = UnTangler()
+        projectInformation: ProjectInformation = self._extractProjectInformation(fqFileName)
+
+        if projectInformation.version == '10':
+            untangler: UnTangler = UnTangler(xmlVersion=XmlVersion.V10)
+        elif projectInformation.version == '11':
+            untangler = UnTangler(xmlVersion=XmlVersion.V11)
+        else:
+            raise UnsupportedVersion(message=f'Unsupported version: {projectInformation.version}')
 
         untangler.untangleFile(fqFileName=fqFileName)
 
@@ -111,7 +126,7 @@ class Reader:
 
         oglProject.toOglProject(untangler.projectInformation)
 
-        assert oglProject.version == OglVersion.version, 'We have mismatched XML versions'
+        assert oglProject.version == XmlVersion.V10.value or oglProject.version == XmlVersion.V11.value, 'We have mismatched XML versions'
         documents: Documents = untangler.documents
         for document in documents.values():
             self.logger.debug(f'Untangled - {document.documentTitle}')
@@ -133,3 +148,9 @@ class Reader:
             oglProject.oglDocuments[oglDocument.documentTitle] = oglDocument
 
         return oglProject
+
+    def _extractProjectInformation(self, fqFileName: str) -> ProjectInformation:
+
+        unTangleProjectInformation: UnTangleProjectInformation = UnTangleProjectInformation(fqFileName=fqFileName)
+
+        return unTangleProjectInformation.projectInformation
